import{N as c}from"./Navbar-2c1FU0Ln.js";import{e as d,ak as u,b as a,l,a4 as f,f as _,g as b,v as p,k as y,aO as I}from"./jwt-decode.esm-D1_tUByX.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-mgEJHNiL.js";import"./constants-7jqnIZTe.js";import"./PhCaretDown.vue--HGNX85x.js";import"./PhPencilSimple.vue-BQ9UZmfW.js";import"./router-C_T7J4_6.js";import"./ts.worker-a-L8fVsa.js";import"./organization-as1KOIfv.js";import"./tables-Bfwm3WSj.js";import"./string-ylr6bQvY.js";import"./keyboard-DoiDCAVB.js";import"./os-BQN_QUk-.js";import"./projectStore-Db_rqhgl.js";import"./project-BjOmkmew.js";import"./organizationSwitcher-Dxk0YZwy.js";import"./cascaderStore-CPu57VpX.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-Bzvhso7c.js";import"./member-CV0NGM-f.js";import"./index-B-Tvm8cT.js";import"./index-DpTdK8zW.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-C3_VbO6w.js";import"./PhNotePencil.vue-CkO0CZld.js";import"./PhSignOut.vue-Ck9r8wDb.js";import"./index-OPVWxf8t.js";import"./index-CTC3WiV4.js";import"./PhPlus.vue-B-yZTLTw.js";import"./omniChatStore-8jMdeQUC.js";import"./files-DaNn6a2y.js";import"./contracts.generated-DWJOmHQ6.js";import"./runnerData-Pn8eb3mv.js";import"./url-CpRE35j8.js";import"./colorHelpers-ljwJdU2S.js";import"./uuid-CvXnVuZ2.js";import"./useLintersStore-8CP47WoG.js";import"./PhCopySimple.vue-CLB6HzUQ.js";import"./PhSparkle.vue-BanPo18h.js";import"./index-BDYT1VjP.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="23fd9fc5-154e-498a-bbf1-0fc95511e3c1",r._sentryDebugIdIdentifier="sentry-dbid-23fd9fc5-154e-498a-bbf1-0fc95511e3c1")}catch{}})();const v={class:"console-layout"},g={class:"console-content"},w=d({__name:"ConsoleLayout",setup(r){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,e=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(e)return{organizationId:e}});return(t,i)=>{const e=f("RouterView");return b(),_("div",v,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",g,[p(e)])])}}}),po=I(w,[["__scopeId","data-v-62f8634d"]]);export{po as default};
//# sourceMappingURL=ConsoleLayout-Bf4TVHbi.js.map
