import{C as t,_ as p}from"./View.vue_vue_type_script_setup_true_lang-wRLPlp8n.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-D1_tUByX.js";import{u as a}from"./projectStore-Db_rqhgl.js";import"./router-C_T7J4_6.js";import"./ts.worker-a-L8fVsa.js";import"./fetch-Car9rSpE.js";import"./tables-Bfwm3WSj.js";import"./string-ylr6bQvY.js";import"./SaveButton-CY2RNFGq.js";import"./ExclamationCircleOutlined-C1DAQPKo.js";import"./CrudView-BqEKJl57.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-BDz3210v.js";import"./constants-7jqnIZTe.js";import"./url-CpRE35j8.js";import"./PhDotsThreeVertical.vue-DpQWeI90.js";import"./index-OPVWxf8t.js";import"./asyncComputed-l-lcqrwY.js";import"./PhPencil.vue--dODCHHP.js";import"./useCodebaseEvents-NUlApXTb.js";import"./contracts.generated-DWJOmHQ6.js";import"./index-CSTRyKdC.js";import"./project-BjOmkmew.js";import"./organizationSwitcher-Dxk0YZwy.js";import"./organization-as1KOIfv.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="e63de636-dc26-4a41-b8e6-90eb721b24db",o._sentryDebugIdIdentifier="sentry-dbid-e63de636-dc26-4a41-b8e6-90eb721b24db")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=a(),e=new t(r.projectId);return(d,c)=>(s(),n(p,{"env-var-repository":m(e),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-cmA2opVf.js.map
